==> dasu_4.11.jar: edu/northwestern/dasu/stats/RemotePeerStatDynamic.java <==
/**
 * Dasu Project
 *
 * File:         DynamicPeerStat.java
 * RCS:          $Id$
 * Description:  DynamicPeerStat class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Oct 17, 2010 at 7:53:45 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.stats
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.stats;

import edu.northwestern.dasu.drools.FactTemplate;
import edu.northwestern.dasu.util.Util;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The DynamicPeerStat class ...
 * Remote Peer Stat Dynamic
 */

public class RemotePeerStatDynamic extends FactTemplate {
	
	public boolean isInteresting;
	public boolean isInterested;
	public boolean rttPending;
	public double ping = -2;
	long currentTime = Util.currentGMTTime();
	int bytesSentToPeer;
	int bytesReceivedFromPeer;
	int currentSendRate;
	int currentReceiveRate;
	boolean isSeed= false;
	String peerIp;
	
	@Override
	public boolean equals(Object obj) {
		
		if (obj instanceof RemotePeerStatDynamic) {

			RemotePeerStatDynamic stat = (RemotePeerStatDynamic) obj;

			return (this.isInteresting == stat.isInteresting) && (this.isInterested == stat.isInterested) &&
				(this.bytesSentToPeer == this.bytesSentToPeer) && (this.bytesReceivedFromPeer == this.bytesReceivedFromPeer) && 
				(this.currentSendRate == stat.currentSendRate) && (this.currentReceiveRate == stat.currentReceiveRate) &&
				(this.isSeed == stat.isSeed);
	
		}
		return false;
		
	}
	
	@Override
	public int hashCode() {
		return (isInteresting?1:0) + (isInterested?1:0) + bytesSentToPeer +
			bytesReceivedFromPeer + currentSendRate + currentReceiveRate;
	}
	
	@Override
	public String toString() {
		return 	isInteresting + " " + isInterested + " " + bytesSentToPeer + " " + bytesReceivedFromPeer +  
		 	" " + currentSendRate + " " + currentReceiveRate + " " + isSeed;

	}

}

==> dasu_5.31.jar: edu/northwestern/dasu/stats/RemotePeerStatDynamic.java <==
/**
 * Dasu Project
 *
 * File:         DynamicPeerStat.java
 * RCS:          $Id$
 * Description:  DynamicPeerStat class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Oct 17, 2010 at 7:53:45 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.stats
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.stats;

import edu.northwestern.dasu.drools.FactTemplate;
import edu.northwestern.dasu.util.Util;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The DynamicPeerStat class ...
 * Remote Peer Stat Dynamic
 */

public class RemotePeerStatDynamic extends FactTemplate {
	
	private static final long serialVersionUID = 3L;
	public boolean isInteresting;
	public boolean isInterested;
	public boolean rttPending;
	public double ping = -2;
	public long currentTime = Util.currentGMTTime();
	public int bytesSentToPeer;
	public int bytesReceivedFromPeer;
	public int currentSendRate;
	public int currentReceiveRate;
	public boolean isSeed= false;
	public String peerIp;
	
	@Override
	public boolean equals(Object obj) {
		
		if (obj instanceof RemotePeerStatDynamic) {

			RemotePeerStatDynamic stat = (RemotePeerStatDynamic) obj;

			return (this.isInteresting == stat.isInteresting) && (this.isInterested == stat.isInterested) &&
				(this.bytesSentToPeer == this.bytesSentToPeer) && (this.bytesReceivedFromPeer == this.bytesReceivedFromPeer) && 
				(this.currentSendRate == stat.currentSendRate) && (this.currentReceiveRate == stat.currentReceiveRate) &&
				(this.isSeed == stat.isSeed);
	
		}
		return false;
		
	}
	
	@Override
	public int hashCode() {
		return (isInteresting?1:0) + (isInterested?1:0) + bytesSentToPeer +
			bytesReceivedFromPeer + currentSendRate + currentReceiveRate;
	}
	
	@Override
	public String toString() {
		return 	isInteresting + " " + isInterested + " " + bytesSentToPeer + " " + bytesReceivedFromPeer +  
		 	" " + currentSendRate + " " + currentReceiveRate + " " + isSeed;

	}

}
